import { declare } from '@babel/helper-plugin-utils';

var index = declare((api, options) => {
  api.assertVersion(7);
  let {
    version
  } = options;
  {
    if (version === undefined) {
      throw new Error("The decorators plugin requires a 'version' option, whose value must be one of: " + "'2023-05', '2023-01', '2022-03', '2021-12', '2018-09', or 'legacy'.");
    }
    if (version !== "2023-05" && version !== "2023-01" && version !== "2022-03" && version !== "2021-12" && version !== "legacy") {
      throw new Error("Unsupported decorators version: " + version);
    }
    if (options.legacy !== undefined) {
      throw new Error(`The .legacy option has been removed in Babel 8. Use .version: "legacy" instead.`);
    }
    if (options.decoratorsBeforeExport !== undefined) {
      throw new Error(`The .decoratorsBeforeExport option has been removed in Babel 8.`);
    }
  }
  return {
    name: "syntax-decorators",
    manipulateOptions({
      generatorOpts
    }, parserOpts) {
      if (version === "legacy") {
        parserOpts.plugins.push("decorators-legacy");
      } else {
        parserOpts.plugins.push(["decorators", {
          allowCallParenthesized: false
        }], "decoratorAutoAccessors");
      }
    }
  };
});

export { index as default };
//# sourceMappingURL=index.js.map
